@@ -529,6 +529,11 @@ class TreeScoreTimewise(timewise.Score):
             for part in measure.get_children_by_type(TreePart):
                 part.adjoin_ties()
 
+    def break_beams(self):
+        for measure in self.get_children_by_type(TreeMeasure):
+            for part in measure.get_children_by_type(TreePart):
+                part.break_beams()
+
     def chord_to_notes(self):
         for measure in self.get_children_by_type(TreeMeasure):
             for part in measure.get_children_by_type(TreePart):
@@ -582,6 +587,7 @@ class TreeScoreTimewise(timewise.Score):
         self.update_types()
         self.update_dots()
         self.group_beams()
+        self.break_beams()
         self.implement_flags_3()
 
     def finish_from_flag_1_to_2(self):
