@@ -21,7 +21,7 @@ class Test(TestCase):
         n.add_child(Arpeggiate())
 
         v = sf.to_stream_voice(1)
-        v.add_to_score(self.score, 1, 1)
+        v.add_to_score(self.score)
 
         result_path = path + '_test_1'
         self.score.write(path=result_path)
